#!/bin/bash
#===============================================================================
#
#          FILE:  first-install.sh
# 
#         USAGE:  first-install.sh 
# 
#   DESCRIPTION:  Script for the first instalation of a platform or product
# 
#        AUTHOR:   Cvetka Milinovic, 
#       COMPANY:  Iskratel
#       VERSION:  1.0
#       CREATED:  12/22/2014 02:45:38 PM CET
#      REVISION:  ---
#===============================================================================

###################################################
# Help function
function show_help()
{
	echo
	echo "Usage:"
	echo "  ${0##*/} <Own_Iface> <Own_IPM> <Own_DGW> <Package_IP_URL>    e.g first-install.sh eth0 192.168.112.12/24 192.168.112.1 http://10.1.9.115/sw-distro/swdistro/an6321gp/AN6321GP_0.0.0.0.000.10" 
}

### Main part ####
if [ -z $4 ]
then
	show_help
	exit 1
fi

echo
echo "########################################################"
echo "# Setting temporary network configuration:"
echo "########################################################"
OWN_IFACE=$1
OWN_IPM=$2
OWN_DGW=$3
PACKAGE_IP_URL=$4
PACKAGE_NAME=$(basename $PACKAGE_IP_URL)
SERVER_IP=`echo $PACKAGE_IP_URL | sed 's%.*//%%' | sed 's%/.*$%%'`

OWN_VLANID=""
OWN_IFACE_PHYS=`echo ${OWN_IFACE} | sed -e 's%\..*%%g'`

if [ "x"$OWN_IFACE != "x"$OWN_IFACE_PHYS ]
then
	OWN_VLANID=`echo ${OWN_IFACE} | sed -e 's%^.*\.%%g'`
fi

ip link set dev $OWN_IFACE_PHYS up
sleep 2

if [ "x"$OWN_VLANID != "x" ]
then
	modprobe 8021q; sleep 1
	vconfig add $OWN_IFACE_PHYS $OWN_VLANID 2> /dev/null
fi

if [ "x`ip addr show dev ${OWN_IFACE} | grep "${OWN_IPM}" | grep "${OWN_IFACE}"`" == "x" ]; then
	ip addr add $OWN_IPM dev $OWN_IFACE
fi

ip link set dev $OWN_IFACE up
sleep 2

ip route del `ip route | grep "default"` 2> /dev/null
ip route add default via $OWN_DGW dev $OWN_IFACE
echo "DONE!"

echo
echo "########################################################"
echo "# Testing SW server network access:"
echo "########################################################"
ping -c 1 ${SERVER_IP} &>/dev/null

# Exit with error if server not reachable
if [ $? -ne 0 ]
then
	echo "Server ${SERVER_IP} not reachable - installation has been canceled."
	exit 1
fi
echo "DONE!"

echo
echo "########################################################"
echo "# Testing SW package network access:"
echo "########################################################"
wget $PACKAGE_IP_URL/product-install-cfg.xml
# Exit with error if server not reachable
if [ $? -ne 0 ]
then
	echo "Package $PACKAGE_IP_URL can not be transfered - installation has been canceled."
	exit 1
fi
rm -f product-install-cfg.xml
echo "DONE!"

# generate ssh-keys
echo
echo "########################################################"
echo "# Generating SSH keys:"
echo "########################################################"
/sbin/ha-ssh-keys generate-server-keys --current-only
ha-ssh-keys sync-user-keys --username=root --current-only
echo "DONE!"

echo
echo "########################################################"
echo "# Generating minimal startup-config:"
echo "########################################################"
cat > /etc/startup-config << EOF
!
hostname localhost
!
system unit-id 1 node-id 1
!
system type standalone
EOF
echo "DONE!"

echo
echo "########################################################"
echo "# Installing the package $PACKAGE_NAME:"
echo "########################################################"
/sbin/element-admin.sh --install --without-db-data --repo-sw-url=$PACKAGE_IP_URL
if [ $? -ne 0 ]
then
	echo "Package $PACKAGE_IP_URL installation FAILED!"
	exit 1
fi

echo
echo "########################################################"
echo "# Activating the package $PACKAGE_NAME:"
echo "########################################################"
/sbin/element-admin.sh --set-active-release --product=RESERVED

echo
echo "########################################################"
echo "# Instalation finished, please reboot..." 
echo "########################################################"
